Tutorials
=========

We have prepared a collection of Jupyter (IPython) notebooks that show how to use the package.

You can view them online or download Python scripts:

https://github.com/TUD-STKS/PyRCN/tree/master/examples

The notebook (digits)[https://github.com/TUD-STKS/PyRCN/blob/master/examples/digits.ipynb] or its corresponding (Python script)[https://github.com/TUD-STKS/PyRCN/blob/master/examples/digits.py] show how to set up an ESN for a small hand-written digit recognition experiment.

Fore more advanced examples, pleas have a look at our (Automatic Music Transcription Repository)[https://github.com/TUD-STKS/Automatic-Music-Transcription], in which we provide an entire feature extraction, training and test pipeline for multipitch tracking and for note onset detection using PyRCN.
